open Godi_package

let makefile gp =
    let version = gp.version in
    let pkgname = gp.pkgname in
    let revision = gp.revision in
    let distname = gp.distname in
    let distfiles = gp.distfiles in
    let categories = gp.categories in
    let master_sites = gp.master_sites in
    let maintainer = gp.maintainer in
    let homepage = gp.homepage in
    let comment = gp.comment in
    let confopt_defaults = gp.confopt_defaults in
    let pkg = gp.pkg in
    let addl_make_flags = gp.addl_make_flags in
    let depends = gp.depends in
    let build_depends = gp.build_depends in
    let has_configure = gp.has_configure in
    let use_gmake = gp.use_gmake in
    let all_target = gp.all_target in
    let all_target_opt = gp.all_target_opt in
    let docfiles = gp.docfiles in

    interpolate file "BSDMakefile.template"

let f ~godi_localbase ~godi_package ~replace =
    let gp = godi_package in

    (* make the directory *)
    let inst_dir = godi_localbase ^ "/build/" ^ gp.makefile.categories
                                        ^ "/" ^ gp.makefile.pkg in

    (* check to see if the directory already exists *)
    (if Util.file_exists inst_dir then
        if replace then
            Util.recursive_unlink inst_dir
        else
            Log.error ("Can't write to " ^ inst_dir ^ ": file exists.");
            Log.die ("Perhaps consider the -replace option?")
    );

    (* mkdirs *)
    let filesdir = inst_dir ^ "/files" in
    let patchesdir = inst_dir ^ "/patches" in
    Util.mkdir inst_dir;
    Util.mkdir patchesdir;

    (* write files *)
    Util.write_file (makefile gp.makefile) (inst_dir ^ "/Makefile");
    Util.write_file gp.descr (inst_dir ^ "/DESCR");
    Util.write_file_opt gp.buildmsg (inst_dir ^ "/BUILDMSG");
    Util.write_file_opt gp.confopts (inst_dir ^ "/CONFOPTS");

    (* copy in patches & files *)
    List.iter (fun patchfile -> Util.copy patchfile patchesdir) gp.patches;
    (match gp.filesdir with
        None -> ()
      | Some fdir -> Util.copydir fdir inst_dir);

    (* generate checksums *)
    let bmake = godi_localbase ^ "/bin/bmake" in
    if Sys.command ("cd " ^ inst_dir ^ " && " ^ bmake ^ " makesum") <> 0 then
        Log.die ("Error generating checksum.");
    if Sys.command ("cd " ^ inst_dir ^ " && " ^ bmake ^ " makepatchsum") <> 0
    then
        Log.die ("Error generating patch checksums.");

    (* copy in the spec file *)
    Util.copy gp.specfile inst_dir;

    print_endline ("Package written to " ^ inst_dir ^ ".")
